Documentation
¶
Overview ¶
Package model provides data structures and helper functions for loading common Oneliner equipment models.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Bus ¶
type Bus struct {
HND int // ASPEN Oneliner equipment handle
Name string // BUSsName
KVNominal float64 // BUSdKVnominal
Number int // BUSnNumber
Area int // BUSnArea
Zone int // BUSnZone
Tap int // BUSnTapBus
Comment string // BUSsComment (aka Memo field)
}
Bus represents a bus equipment data structure. This does not represent all fields from ASPEN model, future fields may be added as needed.
Click to show internal directories.
Click to hide internal directories.